import pathlib
from setuptools import setup, find_packages

HERE = pathlib.Path(__file__).parent
name="color-detect"
version="0.0.1"
author="Korede Bashir"
author_email="bashirkorede@gmail.com"
description="A mini package to work with detecting colors from images"
long_description=(HERE / "README.md").read_text()
long_description_content_type="text/markdown"
url="https://github.com/bashirk/color-detect"
license="MIT"
INSTALL_REQUIRES = [
      'opencv-python',
      'numpy',
      'pandas'
]

'''
with open("README.md", "r") as f:
    long_description = f.read()
'''


setup(
    name=name,
    version=version,
    author=author,
    author_email=author_email,
    description=description,
    long_description=long_description,
    long_description_content_type=long_description_content_type,
    url=url,
    license=license,
    packages=find_packages(),
    install_requires=INSTALL_REQUIRES,
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ]
)



import cv2
import numpy as np
import pandas as pd
import argparse

def  color_detect():
    
    #Creating argument parser to take image path from command line
    ap = argparse.ArgumentParser()
    ap.add_argument('-i', '--image', required=True, help="Image Path")
    args = vars(ap.parse_args())
    img_path = args['image']

    #Reading the image with opencv
    img = cv2.imread(img_path)

    #declaring global variables (are used later on)
    clicked = False
    r = g = b = xpos = ypos = 0

    #Reading csv file with pandas and giving names to each column
    index=["color","color_name","hex","R","G","B"]
    csv = pd.read_csv('colors.csv', names=index, header=None)

    #function to calculate minimum distance from all colors and get the most matching color
    def getColorName(R,G,B):
        minimum = 10000
        for i in range(len(csv)):
            d = abs(R- int(csv.loc[i,"R"])) + abs(G- int(csv.loc[i,"G"]))+ abs(B- int(csv.loc[i,"B"]))
            if(d<=minimum):
                minimum = d
                cname = csv.loc[i,"color_name"]
        return cname

    #function to get x,y coordinates of mouse double click
    def draw_function(event, x,y,flags,param):
        if event == cv2.EVENT_LBUTTONDBLCLK:
            global b,g,r,xpos,ypos, clicked
            clicked = True
            xpos = x
            ypos = y
            b,g,r = img[y,x]
            b = int(b)
            g = int(g)
            r = int(r)
        
    cv2.namedWindow('image')
    cv2.setMouseCallback('image',draw_function)

    while(1):

        cv2.imshow("image",img)
        if (clicked):
    
            #cv2.rectangle(image, startpoint, endpoint, color, thickness)-1 fills entire rectangle 
            cv2.rectangle(img,(20,20), (750,60), (b,g,r), -1)

            #Creating text string to display( Color name and RGB values )
            text = getColorName(r,g,b) + ' R='+ str(r) +  ' G='+ str(g) +  ' B='+ str(b)
            
            #cv2.putText(img,text,start,font(0-7),fontScale,color,thickness,lineType )
            cv2.putText(img, text,(50,50),2,0.8,(255,255,255),2,cv2.LINE_AA)

            #For very light colours we will display text in black colour
            if(r+g+b>=600):
                cv2.putText(img, text,(50,50),2,0.8,(0,0,0),2,cv2.LINE_AA)
                
            clicked=False

        #Break the loop when user hits 'esc' key    
        if cv2.waitKey(20) & 0xFF ==27:
            break
        
    cv2.destroyAllWindows()
